#
# spec file for package lxqt-powermanagement
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-powermanagement
Version:        1.2.0
Release:        bp155.1.10
Summary:        Power Management and Auto-suspend
License:        LGPL-2.1-or-later
Group:          System/GUI/LXQt
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  lxqt-build-tools-devel >= 0.11.0
BuildRequires:  lxqt-globalkeys-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5IdleTime)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5WindowSystem) >= 5.36.0
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui) >= 5.15.0
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xdg)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(lxqt) >= %{version}
#BuildRequires:  pkgconfig(xcb)
Requires:       upower
%requires_eq    libQt5Gui5
Recommends:     %{name}-lang

%description
LXQt daemon for power management and auto-suspend

%lang_package

%prep
%setup -q
# Changing LXQt into X-LXQt in desktop files to be freedesktop compliant and shut rpmlint warnings
#find -name '*desktop.in*' -exec sed -ri 's/(LXQt;)/X-\1/' {} +

%build
%cmake  -DPULL_TRANSLATIONS=No

%install
%cmake_install
%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name} --with-qt

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/lxqt*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/scalable/devices/*.svg
%config %{_sysconfdir}/xdg/autostart/lxqt-powermanagement.desktop

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%{_datadir}/lxqt/translations/lxqt-powermanagement
%{_datadir}/lxqt/translations/lxqt-config-powermanagement

%changelog
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Better tray icon descriptions.
  * Consider the stable state of battery (neither charging nor
    discharging).
  * Fixed the error message "QString::arg: Argument missing".
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Three tray icons are added, with the charge percentage inside them.
    Now, the built-in tray icon can be circular or shaped like a battery.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Idleness checks can be paused from the tray icon for 30
    minutes to 4 hours.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Separate idle watchers for AC and battery.
  * An option to disable idle watcher when the active window is full-screen.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Added a Power keys section for customizing actions of power,
    suspend and hibernate keys.
  * Dropped QProcess deprecated methods.
* Wed Jun 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Don't package icon dirs
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-powermanagement.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * An option is added for changing the display backlight when the computer is idle.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Mon Mar 11 2019 Axel Braun <axel.braun@gmx.de>
- Requires: upower added
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Don't use automatic string conversions
  * Improved cmake scripting
  - set cmake_minimum_required to 3.1.0
  - removed locale compile definitons
  * Moved translations from lxqt-l10n back to lxqt-powermanagement
  - removed obsolete translation fuctionality
  - Added translation promo in README.md
  * Translation updates
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Add support for turning monitor(s) off
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Spell check (add "," and "-")
  * Don't export github templates
  * Adding missing "Comment" section to .desktop files. Fix for https://github.com/lxde/lxqt/issues/1339
  * Added Lithuanian language
  * Drops Qt5Core_VERSION_STRING
  * lxqt-config-powermanagement: set Qt::AA_UseHighDpiPixmaps to true
  * Added QCommandLineParser and basic cli interface to lxqt-config-powermanagement and lxqt-powermanagement
  * Added default CMAKE_BUILD_TYPE and LXQT_POWERMANAGEMENT_PATCH_VERSION
  * added *pl.desktop
  * Fixes a FTBFS in superbuild mode
  * Added merged autostart to CMakeLists.txt
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Update desktop entries and Replace fr_FR by fr
  * Move Italian desktop entry to correct path
  * Update Greek translation (el) Remove country variant from language code
  * Rename LxQt to LXQt everywhere
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Updates the build system to use the Targets infrastructure
  * Rename Power Management module name again
  * Rename LXQt Power Management module name
  * Drops hardcoded /etc/xdg paths
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Portuguese update for .desktop files
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Renamed lxqt-autosuspend.desktop.in --> lxqt-powermanagement.desktop.in
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Default to no action if the action is not specified in the config file
  * BatteryWatcher: Fix indentation
  * Bump year
- Remove post and postun
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Add lxqt-config-powermanagement_da.desktop
  * Create lxqt-config-powermanagement_fr.desktop
  * Make CMakeLists.txt more uniform.
  * Remove cpack (#43)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * README.md: Replace dependency XCB with KIdleTime
  * Idleness Watcher: rely on KIdleTime instead of XCB (#33)
  * fix indents
  * Update and extend README.md
  * Add Catalan translation
  * Add Arabic Translation for Desktop File
  * I18N: Fix Plural Strings (#38)
  * Removes the QEventLoop from the Watcher class
  * build: Use external translations
  * ts-files removal (#34)
  * Bump year Fix licenses, lxqt-powermanagement is LGPL only
  * Fix source language in Italian translation file
  * Italian translation update
  * Update Russian translation Remove ru_RU files
  * Fix typo in Greek translation
  * update: lxqt-powermanagement_hu.ts
  * Add German translation
- Add keyring
- Remove BuildRequirs pkgconfig(xcb), got replaced by KF5IdleTime
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
- Removing patches:
  * fix_desktop_categories.patch - Using sed in spec file now.
* Sat Feb 21 2015 hrvoje.senjan@gmail.com
- lxqt-powermanagement is using private QPA API, which can, and
  does break BC even in point releases, so we need to hardcode
  libQt5Gui5 version
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang Subpackage
- Added Patch
  + fix_desktop_categories.patch to clear rpmlint warnings
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Tue Nov 11 2014 andrea@opensuse.org
- Added license and other documentation
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 sfalken@opensuse.org
- Specfile and Patch cleanup
* Mon May 12 2014 sfalken@opensuse.org
- removed fedora spec, split into subproject
  Del:  lxqt-powermanagement-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE spec
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-powermanagement-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added patch to fix random data error in idlenesswatcher.cpp
  Add:  0003-fix_idlenesswatcher_cpp.patch
* Fri May  9 2014 sfalken@opensuse.org
- Added patches to fix bad includes in sources
  Add:  0001-fix_lid_cpp.patch
  Add:  0002-fix_lidwatcher_cpp.patch
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-powermanagement-0.7.0.tar.xz
  Del:  _service
* Fri Apr  4 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-powermanagement.spec
  Add: lxqt-powermanagement.changes
